@@ -167,12 +167,12 @@ class MapfwBenchmarker:
             timeout = r.json()["timeout"]
             if self.user_timeout:
                 if self.user_timeout<timeout:
-                    warnings.warn(f"The benchmark recommended timeout is {timeout},"
-                                  f" your timeout is {self.user_timeout}."
+                    warnings.warn(f"The benchmark recommended timeout is {timeout}ms,"
+                                  f" your timeout is {self.user_timeout}ms."
                                   f" Consider increasing or removing your custom timeout.")
                 if self.user_timeout>timeout:
-                    warnings.warn(f"The benchmark recommended timeout is {timeout},"
-                                  f" your timeout is {self.user_timeout}."
+                    warnings.warn(f"The benchmark recommended timeout is {timeout}ms,"
+                                  f" your timeout is {self.user_timeout}ms."
                                   f" your timeout will be overwritten by the benchmark recommended timeout.")
                 self.timeout = min(self.user_timeout,timeout)
             else:
